@@ -8,17 +8,17 @@ from enodo.jobs import (
 
 class SeriesJobConfigModel(dict):
 
-    def __init__(self, model, job_type, job_schedule_type, job_schedule,
-                 model_params, activated=True, config_name=None,
+    def __init__(self, module, job_type, job_schedule_type, job_schedule,
+                 module_params, activated=True, config_name=None,
                  silenced=False, requires_job=None):
 
         if not isinstance(activated, bool):
             raise Exception(
                 "Invalid series job config, activated property must be a bool")
 
-        if not isinstance(model, str):
+        if not isinstance(module, str):
             raise Exception(
-                "Invalid series job config, model property must be a string")
+                "Invalid series job config, module property must be a string")
 
         if job_type not in JOB_TYPES:
             raise Exception(
@@ -39,10 +39,10 @@ class SeriesJobConfigModel(dict):
                 "Invalid series job config, "
                 "job_schedule property must be an integer")
 
-        if not isinstance(model_params, dict):
+        if not isinstance(module_params, dict):
             raise Exception(
                 "Invalid series job config, "
-                "model_params property must be a dict")
+                "module_params property must be a dict")
 
         if not isinstance(silenced, bool):
             raise Exception(
@@ -54,11 +54,11 @@ class SeriesJobConfigModel(dict):
 
         super(SeriesJobConfigModel, self).__init__({
             "activated": activated,
-            "model": model,
+            "module": module,
             "job_type": job_type,
             "job_schedule_type": job_schedule_type,
             "job_schedule": job_schedule,
-            "model_params": model_params,
+            "module_params": module_params,
             "config_name": config_name,
             "silenced": silenced,
             "requires_job": requires_job})
@@ -68,8 +68,8 @@ class SeriesJobConfigModel(dict):
         return self.get("activated")
 
     @property
-    def model(self):
-        return self.get("model")
+    def module(self):
+        return self.get("module")
 
     @property
     def job_type(self):
@@ -84,8 +84,8 @@ class SeriesJobConfigModel(dict):
         return self.get("job_schedule")
 
     @property
-    def model_params(self):
-        return self.get("model_params")
+    def module_params(self):
+        return self.get("module_params")
 
     @property
     def config_name(self):
